@@ -1086,6 +1086,14 @@ initcups (void)
   INT_CONSTANT (HTTP_ENCRYPT_REQUIRED);
   INT_CONSTANT (HTTP_ENCRYPT_ALWAYS);
 
+  // Document formats
+  STR_CONSTANT (CUPS_FORMAT_AUTO);
+  STR_CONSTANT (CUPS_FORMAT_COMMAND);
+  STR_CONSTANT (CUPS_FORMAT_PDF);
+  STR_CONSTANT (CUPS_FORMAT_POSTSCRIPT);
+  STR_CONSTANT (CUPS_FORMAT_RAW);
+  STR_CONSTANT (CUPS_FORMAT_TEXT);
+
   // Selected HTTP status codes
   INT_CONSTANT (HTTP_ERROR);
   INT_CONSTANT (HTTP_OK);
